@@ -7,7 +7,7 @@
 import os
 import re
 from pathlib import Path
-from random import random
+from random import randint
 from time import time
 from typing import Union, List
 from urllib.parse import urlparse, quote
@@ -92,7 +92,7 @@ class SessionPage(object):
         if not url or (not go_anyway and self.url == to_url):
             return
         self._url = to_url
-        self._response = self._make_response(to_url, **kwargs)
+        self._response = self._make_response(to_url, **kwargs)[0]
         if self._response:
             self._response.html.encoding = self._response.encoding  # 修复requests_html丢失编码方式的bug
         self._url_available = True if self._response and self._response.ok else False
@@ -104,7 +104,7 @@ class SessionPage(object):
         if not url or (not go_anyway and self._url == to_url):
             return
         self._url = to_url
-        self._response = self._make_response(to_url, mode='post', data=data, **kwargs)
+        self._response = self._make_response(to_url, mode='post', data=data, **kwargs)[0]
         if self._response:
             try:
                 self._response.html.encoding = self._response.encoding  # 修复requests_html丢失编码方式的bug
@@ -128,7 +128,7 @@ class SessionPage(object):
         :param kwargs: 连接参数
         :param file_exists: 若存在同名文件，可选择'rename', 'overwrite', 'skip'方式处理
         :param show_msg: 是否显示下载信息
-        :return: 元组，bool和状态信息（成功时信息为文件名）
+        :return: 元组，bool和状态信息（成功时信息为文件路径）
         """
         goal_path = goal_path or OptionsManager().get_value('paths', 'global_tmp_path')
         if not goal_path:
@@ -138,11 +138,11 @@ class SessionPage(object):
         if 'timeout' not in kwargs:
             kwargs['timeout'] = 20
 
-        r = self._make_response(file_url, mode='get', **kwargs)
+        r, info = self._make_response(file_url, mode='get', **kwargs)
         if not r:
             if show_msg:
-                print('Invalid link')
-            return False, 'Invalid link'
+                print(info)
+            return False, info
         # -------------------获取文件名-------------------
         # header里有文件名，则使用它，否则在url里截取，但不能保证url包含文件名
         if 'Content-disposition' in r.headers:
@@ -150,9 +150,11 @@ class SessionPage(object):
         elif os.path.basename(file_url):
             file_name = os.path.basename(file_url).split("?")[0]
         else:
-            file_name = f'untitled_{time()}_{random.randint(0, 100)}'
+            file_name = f'untitled_{time()}_{randint(0, 100)}'
 
+        file_name = re.sub(r'[\\/*:|<>?"]', '', file_name).strip()
         if rename:  # 重命名文件，不改变扩展名
+            rename = re.sub(r'[\\/*:|<>?"]', '', rename).strip()
             ext_name = file_name.split('.')[-1]
             if rename.lower().endswith(f'.{ext_name}'.lower()) or ext_name == file_name:
                 full_name = rename
@@ -161,7 +163,13 @@ class SessionPage(object):
         else:
             full_name = file_name
 
+        goal_Path = Path(goal_path)
+        goal_path = ''
+        for key, i in enumerate(goal_Path.parts):  # 去除路径中的非法字符
+            goal_path += goal_Path.drive if key == 0 and goal_Path.drive else re.sub(r'[*:|<>?"]', '', i).strip()
+            goal_path += '\\' if i != '\\' and key < len(goal_Path.parts) - 1 else ''
         full_path = Path(f'{goal_path}\\{full_name}')
+
         if full_path.exists():
             if file_exists == 'skip':
                 return False, 'A file with the same name already exists.'
@@ -171,31 +179,29 @@ class SessionPage(object):
                 full_name = avoid_duplicate_name(goal_path, full_name)
                 full_path = Path(f'{goal_path}\\{full_name}')
             else:
-                raise ValueError("file_exists can only be selected in'skip', 'overwrite', 'rename'")
-        # 打印要下载的文件
-        if show_msg:
-            print_txt = full_name if file_name == full_name else f'{file_name} -> {full_name}'
-            print(print_txt)
+                raise ValueError("Argument file_exists can only be 'skip', 'overwrite', 'rename'.")
+
+        Path(goal_path).mkdir(parents=True, exist_ok=True)
+
+        if show_msg:  # 打印要下载的文件
+            print(full_name if file_name == full_name else f'{file_name} -> {full_name}')
             print(f'Downloading to: {goal_path}')
+
         # -------------------开始下载-------------------
         # 获取远程文件大小
         file_size = int(r.headers['Content-Length']) if 'Content-Length' in r.headers else None
-        # 已下载文件大小和下载状态
-        downloaded_size, download_status = 0, False
-        # 完整的存放路径
+        downloaded_size, download_status = 0, False  # 已下载文件大小和下载状态
         try:
             with open(str(full_path), 'wb') as tmpFile:
                 for chunk in r.iter_content(chunk_size=1024):
                     if chunk:
                         tmpFile.write(chunk)
-                        # 如表头有返回文件大小，显示进度
-                        if show_msg and file_size:
+                        if show_msg and file_size:  # 如表头有返回文件大小，显示进度
                             downloaded_size += 1024
                             rate = downloaded_size / file_size if downloaded_size < file_size else 1
                             print('\r {:.0%} '.format(rate), end="")
         except Exception as e:
             download_status, info = False, f'Download failed.\n{e}'
-            raise
         else:
             download_status, info = (False, 'File size is 0.') if full_path.stat().st_size == 0 else (True, 'Success.')
         finally:
@@ -206,19 +212,19 @@ class SessionPage(object):
         # -------------------显示并返回值-------------------
         if show_msg:
             print(info)
-        info = full_name if download_status else info
+        info = f'{goal_path}\\{full_name}' if download_status else info
         return download_status, info
 
-    def _make_response(self, url: str, mode: str = 'get', data: dict = None, **kwargs) -> Union[HTMLResponse, bool]:
+    def _make_response(self, url: str, mode: str = 'get', data: dict = None, **kwargs) -> tuple:
         """生成response对象。接收mode参数，以决定用什么方式。
         :param url: 要访问的网址
-        :param mode: 'get','post'中选择
+        :param mode: 'get', 'post' 中选择
         :param data: 提交的数据
         :param kwargs: 其它参数
         :return: Response对象
         """
         if mode not in ['get', 'post']:
-            raise ValueError("mode must be 'get' or 'post'.")
+            raise ValueError("Argument mode can only be 'get' or 'post'.")
         url = quote(url, safe='/:&?=%;#@')
 
         # 设置referer和host值
@@ -244,8 +250,8 @@ class SessionPage(object):
                 r = self.session.get(url, **kwargs)
             elif mode == 'post':
                 r = self.session.post(url, data=data, **kwargs)
-        except:
-            return_value = False
+        except Exception as e:
+            return None, e
         else:
             headers = dict(r.headers)
             if 'Content-Type' not in headers or 'charset' not in headers['Content-Type']:
@@ -259,5 +265,4 @@ class SessionPage(object):
             # 避免存在退格符导致乱码或解析出错
             r._content = r.content if 'stream' in kwargs and kwargs['stream'] else r.content.replace(b'\x08', b'\\b')
             r.encoding = charset
-            return_value = r
-        return return_value
+            return r, 'Success'
